
--[[

A Combat Analysis Tree Panel contains a Tree View with
a scrollable bar. It expects to have Combat Analysis
Tree Nodes added, which mimic the LOTRO tree style.

]]--


_G.CombatAnalysisTreePanel = class(Turbine.UI.Control);

-- configuration parameters
CombatAnalysisTreePanel.indentationWidth = 16;
CombatAnalysisTreePanel.treeNodePadding = 2;
CombatAnalysisTreePanel.valueLabelWidth = 40;
CombatAnalysisTreePanel.minLabelWidth = 38;

function CombatAnalysisTreePanel:Constructor()
	Turbine.UI.Control.Constructor(self);
	
	self.selectedPlayer = nil;
	self.selectedSkill = nil;
	
	self.treeView = Turbine.UI.TreeView();
	self.treeView:SetParent(self);
	self.treeView:SetIndentationWidth(CombatAnalysisTreePanel.indentationWidth);
	self.treeView:SetMouseVisible(false);

	-- Give the tree view a scroll bar.
	self.scrollBar = Turbine.UI.Lotro.ScrollBar();
	self.scrollBar:SetOrientation(Turbine.UI.Orientation.Vertical);
	self.scrollBar:SetParent(self);
	self.scrollBar:SetTop(1);
	self.scrollBar:SetWidth(10);
	
	self.treeView:SetVerticalScrollBar(self.scrollBar);
	
	self.rootNodes = self.treeView:GetNodes();
end

function CombatAnalysisTreePanel:Layout()
	local w,h = self:GetSize();
	
	self.treeView:SetSize(w,h);
	self.scrollBar:SetLeft(w-10);
	self.scrollBar:SetHeight(h-14);
	self:DepthFirstTraversal(CombatAnalysisTreePanel.LayoutNode);
end

function CombatAnalysisTreePanel:LayoutNode(node,depth)
	local w = self:GetWidth();
	
	node:SetWidth(w-(depth-1)*CombatAnalysisTreePanel.indentationWidth);
	node:Layout();
end

function CombatAnalysisTreePanel:DepthFirstTraversal(operation)
	-- traverse children
	for i=1,self.rootNodes:GetCount() do
		self:DepthFirstTraversalInternal(operation,self.rootNodes:Get(i),1);
	end
end

function CombatAnalysisTreePanel:DepthFirstTraversalInternal(operation,node,depth)
	-- perform operation on node
	operation(self,node,depth);
	-- traverse children
	local children = node:GetChildNodes();
	for i=1,children:GetCount() do
		self:DepthFirstTraversalInternal(operation,children:Get(i),depth+1);
	end
end
